import { Connection, PublicKey } from "@solana/web3.js";
import { ITokenBonding } from "@strata-foundation/spl-token-bonding";
import { ITokenRef } from "@strata-foundation/spl-token-collective";
import { UseAccountState } from "./useAccount";
import { IUseTokenMetadataResult } from "./useTokenMetadata";
export declare const WUMBO_TWITTER_TLD: PublicKey;
export declare function getTwitterClaimedTokenRefKey(connection: Connection, handle: string, collective?: PublicKey, tld?: PublicKey): Promise<PublicKey>;
export declare function getTwitterUnclaimedTokenRefKey(handle: string, collective?: PublicKey, tld?: PublicKey): Promise<PublicKey>;
export declare const useUnclaimedTwitterTokenRefKey: (name: string | undefined, collective?: PublicKey | undefined, tld?: PublicKey) => {
    result: PublicKey | undefined;
    loading: boolean;
};
export declare const useClaimedTwitterTokenRefKey: (name: string | undefined, collective?: PublicKey, tld?: PublicKey) => {
    result: PublicKey | undefined;
    loading: boolean;
};
export declare const useClaimedTokenRefKey: (owner: PublicKey | undefined, collective?: PublicKey) => PublicKey | undefined;
/**
 * Get a token ref from the bonding instance
 *
 * @param tokenBonding
 * @returns
 */
export declare function useTokenRefFromBonding(tokenBonding: PublicKey | undefined): UseAccountState<ITokenRef>;
/**
 * Given a social token mint, get the social token TokenRef
 *
 * @param mint
 * @returns
 */
export declare function useReverseTokenRef(mint: PublicKey | undefined): UseAccountState<ITokenRef>;
/**
 * Get the token ref for this wallet
 * @param owner
 * @returns
 */
export declare function useClaimedTokenRef(owner: PublicKey | undefined): UseAccountState<ITokenRef>;
/**
 * Get a TokenRef using a twitter handle name service lookup on `name`. Searches for `name`, then grabs the owner.
 *
 * If the name is unclaimed, grabs the unclaimed token ref if it exists
 *
 * @param name
 * @param collective
 * @param tld
 * @returns
 */
export declare const useTwitterTokenRef: (name: string | undefined, collective: PublicKey | undefined, tld?: PublicKey) => UseAccountState<ITokenRef>;
export interface IUseSocialTokenMetadataResult extends IUseTokenMetadataResult {
    tokenBonding?: ITokenBonding;
    tokenRef?: ITokenRef;
}
/**
 * Get all metadata associated with a given wallet's social token.
 *
 * @param owner
 * @returns
 */
export declare function useSocialTokenMetadata(owner: PublicKey | undefined): IUseSocialTokenMetadataResult;
//# sourceMappingURL=tokenRef.d.ts.map